# Copyright 2019 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# NOTE: This file is auto generated by the elixir code generator program.
# Do not edit this file manually.

defmodule GoogleApi.HealthCare.V1beta1.Model.Hl7V2NotificationConfig do
  @moduledoc """
  Specifies where and whether to send notifications upon changes to a
  data store.

  ## Attributes

  *   `filter` (*type:* `String.t`, *default:* `nil`) - Restricts notifications sent for messages matching a filter. If this is
      empty, all messages are matched. Syntax:
      https://cloud.google.com/appengine/docs/standard/python/search/query_strings

      The following fields and functions are available for filtering:

      *  `message_type`, from the MSH-9.1 field. For example,
      `NOT message_type = "ADT"`.
      *  `send_date` or `sendDate`, the YYYY-MM-DD date the message was sent in
      the dataset's time_zone, from the MSH-7 segment. For example,
      `send_date < "2017-01-02"`.
      *  `send_time`, the timestamp when the message was sent, using the
      RFC3339 time format for comparisons, from the MSH-7 segment. For example,
      `send_time < "2017-01-02T00:00:00-05:00"`.
      *  `send_facility`, the care center that the message came from, from the
      MSH-4 segment. For example, `send_facility = "ABC"`.
      *  `PatientId(value, type)`, which matches if the message lists a patient
      having an ID of the given value and type in the PID-2, PID-3, or PID-4
      segments. For example, `PatientId("123456", "MRN")`.
      *  `labels.x`, a string value of the label with key `x` as set using the
      Message.labels
      map. For example, `labels."priority"="high"`. The operator `:*` can be
      used to assert the existence of a label. For example,
      `labels."priority":*`.
  *   `pubsubTopic` (*type:* `String.t`, *default:* `nil`) - The [Cloud Pub/Sub](https://cloud.google.com/pubsub/docs/) topic that
      notifications of changes are published on. Supplied by the client. The
      notification is a `PubsubMessage` with the following fields:

      *  `PubsubMessage.Data` contains the resource name.
      *  `PubsubMessage.MessageId` is the ID of this notification. It is
      guaranteed to be unique within the topic.
      *  `PubsubMessage.PublishTime` is the time when the message was
      published.

      Note that notifications are only sent if the topic is non-empty. [Topic
      names](https://cloud.google.com/pubsub/docs/overview#names) must be
      scoped to a project. Cloud Healthcare API service account must have
      publisher permissions on the given Pub/Sub topic. Not having adequate
      permissions causes the calls that send notifications to fail.

      If a notification can't be published to Cloud Pub/Sub, errors are
      logged to Cloud Logging. For more information, see
      [Viewing error logs in Cloud Logging](/healthcare/docs/how-tos/logging).
  """

  use GoogleApi.Gax.ModelBase

  @type t :: %__MODULE__{
          :filter => String.t(),
          :pubsubTopic => String.t()
        }

  field(:filter)
  field(:pubsubTopic)
end

defimpl Poison.Decoder, for: GoogleApi.HealthCare.V1beta1.Model.Hl7V2NotificationConfig do
  def decode(value, options) do
    GoogleApi.HealthCare.V1beta1.Model.Hl7V2NotificationConfig.decode(value, options)
  end
end

defimpl Poison.Encoder, for: GoogleApi.HealthCare.V1beta1.Model.Hl7V2NotificationConfig do
  def encode(value, options) do
    GoogleApi.Gax.ModelBase.encode(value, options)
  end
end
